@@ -194,6 +194,8 @@ def create_folders(project_name):
 def create_project(project_name):
     create_folders(project_name)
     project_name = clean_name(project_name)
+
+    # Create pipeline files
     create_pipeline_file(project_name, directories['artifacts'], 'shared_artifacts')
     create_pipeline_file(project_name, directories['preprocessor'], 'preprocess')
     create_pipeline_file(project_name, directories['predictors'], 'predictor')
@@ -203,39 +205,33 @@ def create_project(project_name):
     create_pipeline_file(project_name, directories['pipeline'], 'pipeline')
     create_pipeline_file(project_name, directories['main'], 'pipeline_test', False)
 
+    # Create schema files
     create_schema_file(project_name, directories['schema'], 'inputs')
     create_schema_file(project_name, directories['schema'], 'outputs')
     create_schema_file(project_name, directories['schema'], '__init__', False)
 
+    # Create tester files
     create_tester_file(project_name, directories['tester'], 'general_tester', False)
     create_tester_file(project_name, directories['tester'], 'evaluator', False)
     create_schema_file(project_name, directories['test_schema'], 'test_input', False)
     create_schema_file(project_name, directories['test_schema'], 'test_output', False)
 
+    # Create server files
     create_server_file(project_name, directories['server'], 'main', False)
     create_server_file(project_name, directories['server'], 'test_server_post', False)
     create_server_file(project_name, directories['server'], 'pool', False)
     create_server_file(project_name, directories['server'], 'token_generator', False)
     create_server_file(project_name, directories['server'], '__init__', False)
-    # create_init_file(directories['server'] + '/__init__.py', 'from server.main import app\nfrom server.pool import InstancePool')
-    # create_tester_file(project_name, directories['trainer'], 'trainer')
-    # create_pipeline_file(project_name, 'labelizer')
-    # create_pipeline_file(project_name, 'pipeline')
-    #
+
     create_project_config_json()
     create_project_gitignore()
     create_server_config_json()
     copy_deploy_files(directories['main'])
-    # create_dvc_init_file()
-    # create_git_init_file()
+    copy_cloud_eval_files(directories['main'])
+
     change_to_project_dir()
     run_dvc_init()
     run_git_init()
-    #
-    # create_tester_file(project_name, 'dataset')
-    # create_tester_file(project_name, 'reporter')
-    # create_tester_file(project_name, 'tester')
-    # create_tester_file(project_name, 'tester_server')
 
 
 def create_main_folders(targetDir, baseDir):
@@ -597,6 +593,7 @@ def copy_cloud_eval_files(main_dir):
         currentPipelineFolder = main_dir
     service_folder = str(currentPipelineFolder)
     service_name = service_folder.split('/')[-1]
+    project_name_no_underscore = clean_existing_project_name(service_name)
     dir = os.path.join(__location__, 'cli/tester/cloud_eval/')
     listOfFiles = list()
     conflicted_files = []
@@ -612,6 +609,7 @@ def copy_cloud_eval_files(main_dir):
                     data = file.read()
                     data = data.replace('{name-your-service}', service_name)
                     data = data.replace('{name-your-artifacts}', service_name)
+                    data = data.replace('generatedProjectName', project_name_no_underscore)
                     dirToCreate = ''
                     if main_dir:
                         dirToCreate = main_dir + '/cloud_eval/'
