@@ -4,8 +4,8 @@ import numpy as np
 
 from server.token_generator import tokenGenerator
 
-j = tokenGenerator()
-jwtToken = j.generateToken('DEFAULT_Conf')
+t = tokenGenerator()
+jwtToken = t.generateToken('STG_Conf')
 global_headers = {
     'x-token': 'fake-super-secret-token',
     'Authorization': 'Bearer ' + jwtToken
